@@ -920,9 +920,7 @@ GDALDataset *USGSDEMDataset::Open(GDALOpenInfo *poOpenInfo)
     if (poOpenInfo->eAccess == GA_Update)
     {
         delete poDS;
-        CPLError(CE_Failure, CPLE_NotSupported,
-                 "The USGSDEM driver does not support update access to existing"
-                 " datasets.\n");
+        ReportUpdateNotSupportedByDriver("USGSDEM");
         return nullptr;
     }
 
@@ -966,47 +964,10 @@ void GDALRegister_USGSDEM()
                               "USGS Optional ASCII DEM (and CDED)");
     poDriver->SetMetadataItem(GDAL_DMD_HELPTOPIC,
                               "drivers/raster/usgsdem.html");
-    poDriver->SetMetadataItem(GDAL_DMD_CREATIONDATATYPES, "Int16");
-    poDriver->SetMetadataItem(
-        GDAL_DMD_CREATIONOPTIONLIST,
-        "<CreationOptionList>"
-        "   <Option name='PRODUCT' type='string-select' description='Specific "
-        "Product Type'>"
-        "       <Value>DEFAULT</Value>"
-        "       <Value>CDED50K</Value>"
-        "   </Option>"
-        "   <Option name='TOPLEFT' type='string' description='Top left product "
-        "corner (i.e. 117d15w,52d30n'/>"
-        "   <Option name='RESAMPLE' type='string-select' "
-        "description='Resampling kernel to use if resampled.'>"
-        "       <Value>Nearest</Value>"
-        "       <Value>Bilinear</Value>"
-        "       <Value>Cubic</Value>"
-        "       <Value>CubicSpline</Value>"
-        "   </Option>"
-        "   <Option name='TEMPLATE' type='string' description='File to default "
-        "metadata from.'/>"
-        "   <Option name='DEMLevelCode' type='int' description='DEM Level (1, "
-        "2 or 3 if set)'/>"
-        "   <Option name='DataSpecVersion' type='int' description='Data and "
-        "Specification version/revision (eg. 1020)'/>"
-        "   <Option name='PRODUCER' type='string' description='Producer Agency "
-        "(up to 60 characters)'/>"
-        "   <Option name='OriginCode' type='string' description='Origin code "
-        "(up to 4 characters, YT for Yukon)'/>"
-        "   <Option name='ProcessCode' type='string' description='Processing "
-        "Code (8=ANUDEM, 9=FME, A=TopoGrid)'/>"
-        "   <Option name='ZRESOLUTION' type='float' description='Scaling "
-        "factor for elevation values'/>"
-        "   <Option name='NTS' type='string' description='NTS Mapsheet name, "
-        "used to derive TOPLEFT.'/>"
-        "   <Option name='INTERNALNAME' type='string' description='Dataset "
-        "name written into file header.'/>"
-        "</CreationOptionList>");
+
     poDriver->SetMetadataItem(GDAL_DCAP_VIRTUALIO, "YES");
 
     poDriver->pfnOpen = USGSDEMDataset::Open;
-    poDriver->pfnCreateCopy = USGSDEMCreateCopy;
     poDriver->pfnIdentify = USGSDEMDataset::Identify;
 
     GetGDALDriverManager()->RegisterDriver(poDriver);
